==> fonts-hack_2.019.orig.tar.gz: Hack-2.019/CONTRIBUTORS.md <==
# Contributors

## Hack

### Core Development Team

- Chris Simpkins ([@chrissimpkins](https://github.com/chrissimpkins)) - project lead
- David van Gemeren ([@burodepeper](https://github.com/burodepeper)) - typeface usability
- JM ([@jublo](https://github.com/jublo)) - typeface design, web development

### Hinting / Instruction Sets
- Werner Lemberg

### Powerline Glyphs
- Carlo Abelli
- Justin Anderson
- Matthias Bilger
- Alpha Chen
- Benjamin Chrétien
- Marvin Frommhold
- Tim Heckman
- Serkan Hosca
- Jon Linklater-Johnson
- Giovanni Lanzani
- Caleb Maclennan
- Joel McCance
- Robin McCorkell
- Mack Stump
- Daniele Tricoli

### Language Set Suggestions, Design, and Proofing
- Dmitry Maslennikov - Cyrillic set
- Perry E. Metzger - Greek set
- Timothée Poisot - Greek set
- Damien Pollet - Esperanto set
- Michael Schierl - MES-1 set, Esperanto set
- Roman Sotnikov - Cyrillic set
- Ivan Starkov - Cyrillic set
- Nikos Tzanos - Greek set
- Alexei Volkov - Cyrillic set
- @achkasov - Cyrillic set
- @Bfgeshka - Cyrillic set
- @rafaeln - Kĩsêdjê set
- @xstee (Leonid) - Cyrillic set

### Testing
- Jameel Al-Aziz
- Serj Alimsky
- Aric Belsito
- Sven Busse
- P.F. Chimento
- Ryan Dlugosz
- Felix Dreissig
- Gavin Eadie
- Jason Evans
- Daniel Fitzpatrick
- Thilo Frommeyer
- Trevor Hayes
- Jorg Heymans
- Alexander Hofbauer
- Ken J.
- Jacek Jędrzejewski
- Markus Jevring
- Pete Johanson
- Serg Koles
- Zach Langbert
- Fabio Alessandro Locati
- Jesús Martínez
- Dave Merrill
- Darius Niemczyk
- Fernanda Parisi
- Adam Quaile
- Christopher Rucinski
- Marek Šesták
- Rogier Spieker
- Günther Stadler
- Christopher J. Stehno
- James Taylor
- Manuel Uberti
- David Van Gemeren
- Matthew Wesley
- Gustaf Zetterlund
- 张标 (@angrilove)
- @duud
- @hrj
- @iamklutch
- @legovini
- @MaxKh
- @Paul-v-H
- @schauveau
- @ScuzzyEye
- @tbrisbane

## DejaVu

- Štěpán Roh
- Sander Vesik
- Andrey Panov
- Ben Laenen
- Tim May
- David Jež
- David Lawrence Ramsey
- Danilo Šegan
- Eugeniy Meshcheryakov
- Keenan Pepper
- Denis Jacquerye
- Gee Fung Sit
- Rémy Oudompheng
- Roozbeh Pournader
- Vasek Stoudulka
- Ognan Kulev
- John Karp
- Lars Christensen

## Bitstream Vera

- Jim Lyles

==> fonts-hack_2.020.orig.tar.gz: Hack-2.020/CONTRIBUTORS.md <==
# Contributors

## Hack

### Source Foundry Development Team

- Chris Simpkins ([@chrissimpkins](https://github.com/chrissimpkins))
- David van Gemeren ([@burodepeper](https://github.com/burodepeper))
- Michael "Tex" Hex ([@texhex](https://github.com/texhex))


### Glyph Design

- JM

### Hinting / Instruction Sets
- Werner Lemberg

### Powerline Glyph Set
- Carlo Abelli
- Justin Anderson
- Matthias Bilger
- Alpha Chen
- Benjamin Chrétien
- Marvin Frommhold
- Tim Heckman
- Serkan Hosca
- Jon Linklater-Johnson
- Giovanni Lanzani
- Caleb Maclennan
- Joel McCance
- Robin McCorkell
- Mack Stump
- Daniele Tricoli

### Language Set Design and Proofing
- Dmitry Maslennikov - Cyrillic set
- Perry E. Metzger - Greek set
- Gleb Nemshilov - Cyrillic set
- Vladimir Novoseltev - Cyrillic set
- Timothée Poisot - Greek set
- Damien Pollet - Esperanto set
- Michael Schierl - MES-1 set, Esperanto set
- Roman Sotnikov - Cyrillic set
- Ivan Starkov - Cyrillic set
- Nikos Tzanos - Greek set
- Alexei Volkov - Cyrillic set
- @achkasov - Cyrillic set
- @Bfgeshka - Cyrillic set
- @rafaeln - Kĩsêdjê set
- @xstee (Leonid) - Cyrillic set


### Web Development

- JM


### Redistribution & Installation

- Guilherme Amadio - Linux
- Helio Chissini de Castro - Linux
- Michael "Tex" Hex - Windows
- Caleb Maclennan - Linux, OS X
- @rahilwazir - Linux
- Jakub Žitný - NPM


### DejaVu

- Štěpán Roh
- Sander Vesik
- Andrey Panov
- Ben Laenen
- Tim May
- David Jež
- David Lawrence Ramsey
- Danilo Šegan
- Eugeniy Meshcheryakov
- Keenan Pepper
- Denis Jacquerye
- Gee Fung Sit
- Rémy Oudompheng
- Roozbeh Pournader
- Vasek Stoudulka
- Ognan Kulev
- John Karp
- Lars Christensen

### Bitstream Vera

- Jim Lyles


### Testing
- Jameel Al-Aziz
- Serj Alimsky
- Aric Belsito
- Matthias Bilger
- Sven Busse
- P.F. Chimento
- Ryan Dlugosz
- Felix Dreissig
- Gavin Eadie
- Jason Evans
- Daniel Fitzpatrick
- Thilo Frommeyer
- David van Gemeren
- Trevor Hayes
- Michael "Tex" Hex
- Jorg Heymans
- Alexander Hofbauer
- Ken J.
- Jacek Jędrzejewski
- Markus Jevring
- Pete Johanson
- Anton Kalmykov
- Serg Koles
- Zach Langbert
- Fabio Alessandro Locati
- JM
- Jesús Martínez
- Dave Merrill
- Darius Niemczyk
- Fernanda Parisi
- Adam Quaile
- Christopher Rucinski
- Kevin S
- Marek Šesták
- Rogier Spieker
- Günther Stadler
- Christopher J. Stehno
- James Taylor
- Manuel Uberti
- Matthew Wesley
- Gustaf Zetterlund
- 张标 (@angrilove)
- @duud
- @hrj
- @iamklutch
- @legovini
- @MaxKh
- @Paul-v-H
- @schauveau
- @ScuzzyEye
- @tbrisbane
